==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/ThisYearExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WrapperExpressionDescriptionMetadata } from "./WrapperExpressionDescriptionMetadata";
import { ThisYearExpressionDescription } from "./ThisYearExpressionDescription";
/**
 * @hidden
 */
var ThisYearExpressionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ThisYearExpressionDescriptionMetadata, _super);
    function ThisYearExpressionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ThisYearExpressionDescriptionMetadata.b = function (a) {
        if (ThisYearExpressionDescriptionMetadata.a == null) {
            ThisYearExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ThisYearExpressionDescriptionMetadata.c(ThisYearExpressionDescriptionMetadata.a);
        }
        if (a.j(ThisYearExpressionDescriptionMetadata.a)) {
            return;
        }
        a.y(ThisYearExpressionDescriptionMetadata.a);
    };
    ThisYearExpressionDescriptionMetadata.c = function (a) {
        WrapperExpressionDescriptionMetadata.c(a);
    };
    ThisYearExpressionDescriptionMetadata.d = function (a) {
        ThisYearExpressionDescriptionMetadata.b(a);
        a.aa("ThisYearExpression", function () { return new ThisYearExpressionDescription(); });
        a.z("ThisYearExpression", ThisYearExpressionDescriptionMetadata.a);
    };
    ThisYearExpressionDescriptionMetadata.$t = markType(ThisYearExpressionDescriptionMetadata, 'ThisYearExpressionDescriptionMetadata');
    ThisYearExpressionDescriptionMetadata.a = null;
    return ThisYearExpressionDescriptionMetadata;
}(Base));
export { ThisYearExpressionDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/ThisYearExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WrapperExpressionDescriptionMetadata } from "./WrapperExpressionDescriptionMetadata";
import { ThisYearExpressionDescription } from "./ThisYearExpressionDescription";
/**
 * @hidden
 */
var ThisYearExpressionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ThisYearExpressionDescriptionMetadata, _super);
    function ThisYearExpressionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ThisYearExpressionDescriptionMetadata.b = function (a) {
        if (ThisYearExpressionDescriptionMetadata.a == null) {
            ThisYearExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ThisYearExpressionDescriptionMetadata.c(ThisYearExpressionDescriptionMetadata.a);
        }
        if (a.k(ThisYearExpressionDescriptionMetadata.a)) {
            return;
        }
        a.aa(ThisYearExpressionDescriptionMetadata.a);
    };
    ThisYearExpressionDescriptionMetadata.c = function (a) {
        WrapperExpressionDescriptionMetadata.c(a);
    };
    ThisYearExpressionDescriptionMetadata.d = function (a) {
        ThisYearExpressionDescriptionMetadata.b(a);
        a.ac("ThisYearExpression", function () { return new ThisYearExpressionDescription(); });
        a.ab("ThisYearExpression", ThisYearExpressionDescriptionMetadata.a);
    };
    ThisYearExpressionDescriptionMetadata.$t = markType(ThisYearExpressionDescriptionMetadata, 'ThisYearExpressionDescriptionMetadata');
    ThisYearExpressionDescriptionMetadata.a = null;
    return ThisYearExpressionDescriptionMetadata;
}(Base));
export { ThisYearExpressionDescriptionMetadata };
